@@ -14,11 +14,11 @@ Games::Cards::ShuffleTrack - Track cards through shuffles and cuts
 
 =head1 VERSION
 
-Version 0.03_3
+Version 0.03_4
 
 =cut
 
-our $VERSION = '0.03_3';
+our $VERSION = '0.03_4';
 
 my $cut_limits = {
 	normal  => [0.19, 0.82], # on a 52 cards deck, cut between 10 and 43 cards
@@ -46,6 +46,27 @@ my $shortcuts = {
     'bottom'  => -1,
 };
 
+my $expressions = {
+	A 	=> qr/A[CHSD]/,
+	2 	=> qr/2[CHSD]/,
+	3 	=> qr/3[CHSD]/,
+	4 	=> qr/4[CHSD]/,
+	5 	=> qr/5[CHSD]/,
+	6 	=> qr/6[CHSD]/,
+	7 	=> qr/7[CHSD]/,
+	8 	=> qr/8[CHSD]/,
+	9 	=> qr/9[CHSD]/,
+	10 	=> qr/10[CHSD]/,
+	J 	=> qr/J[CHSD]/,
+	Q 	=> qr/Q[CHSD]/,
+	K 	=> qr/K[CHSD]/,
+
+	C 	=> qr/(?:[A23456789JQK]|10)C/,
+	H 	=> qr/(?:[A23456789JQK]|10)H/,
+	S 	=> qr/(?:[A23456789JQK]|10)S/,
+	D 	=> qr/(?:[A23456789JQK]|10)D/,
+};
+
 
 =head1 SYNOPSIS
 
@@ -268,6 +289,99 @@ sub turn {
 	return $self->_set_deck( reverse @{$self->get_deck} );
 }
 
+=head3 count
+
+Counts how many cards with specific characteristics are in the deck.
+
+	# how many tens
+	$deck->count( '10' );
+
+	# how many Clubs
+	$deck->count( 'C' );
+
+	# how many Clubs and Hearts
+	my ($clubs, $hearts) = $deck->count( 'C', 'H' );
+	my $clubs_and_hearts = $deck->count( 'C', 'H' );
+
+	# how many Jokers
+	$deck->count( 'Joker' );
+
+Since you can add whichever card you want to the deck, it should be noted how searching for values and suits works:
+
+=over 4
+
+=item * If looking for a value from 2 to A, you'll get the amount of cards with that value and one of the four suits
+
+=item * If looking for a suit (C, H, S, D), you'll get the amount of cards with a value from 2 through Ace and that suit
+
+=item * If looking for anything else, that something is compared to the whole card
+
+=back
+
+It is important to note:
+
+	my $total = $deck->count( 'JC' );   # holds 4
+	my $total = $deck->count( 'C', J ); # holds 16, because the JC is only counted once
+	my @total = $deck->count( 'C', J ); # holds (13, 4)
+
+Also:
+
+	$deck->put( 'Joker' );
+	$deck->put( 'Signed Joker' );
+	$deck->count( 'Joker' ); # returns 2
+
+	$deck->put( 'Signed 4C' );
+	$deck->count( '4C' ); # returns 2, because you didn't removed the previous one
+
+=cut
+
+sub count {
+	my $self = shift;
+	my @results;
+
+	if ( wantarray and @_ > 1 ) {
+		return $self->_count_each( @_ );
+	}
+	else {
+		return $self->_count_all( @_ );
+	}
+}
+
+sub _count_each {
+	my $self = shift;
+	my @results;
+	while (my $param = shift) {
+		if ( exists $expressions->{$param} ) {
+			push @results, scalar grep { /$expressions->{$param}/ } @{$self->get_deck};
+		}
+		else {
+			push @results, scalar grep { /$param/ } @{$self->get_deck};
+		}
+	}
+	return @results;
+}
+
+sub _count_all {
+	my $self = shift;
+
+	my @expressions;
+	for my $param (@_) {
+		push @expressions, exists $expressions->{$param} ?
+							$expressions->{$param} :
+							qr/$param/x,
+	}
+
+	my @results;
+	for my $card (@{$self->get_deck}) {
+
+		if (any { $card =~ $_ } @expressions) {
+			push @results, $card;
+		}
+
+	}
+	return scalar @results;
+}
+
 
 =head2 Shuffling
 
@@ -963,6 +1077,11 @@ You can still do a false deal to a pile:
 sub deal {
 	my $self = shift;
 
+	if (not $self->size) {
+		warn "Tried to deal without cards.\n";
+		return $self;
+	}
+
 	my $deal        = 'top';
 	my $destination = undef;
 	while (my $param = shift) {
@@ -1195,6 +1314,59 @@ sub _is_shortcut {
 }
 
 
+=head1 GLOSSARY
+
+The following is not a comprehensive list of gambling terms; it is simply a list of some terms used somewhere in this module that may be useful.
+
+The text has been taken verbatim from The Expert at the Card Table.
+
+=over 4
+
+=item * Stock
+
+That portion of the deck that contains certain cards, placed in some particular order for dealing; or certain
+desirable cards placed at top or bottom of the deck.
+
+=item * Run
+
+To draw off one card at a time during the process of the hand shuffle. There is little or no difficulty in acquiring
+perfect ability to run the whole deck through in this manner with the utmost rapidity. The left thumb presses
+lightly on the top card, the right hand alone making the movement necessary to shuffle.
+
+=item * Break
+
+A space or division held in the deck. While shuffling it is held at the end by the right thumb. It is formed under
+the in-jog when about to under cut for the shuffle, by pushing the in-jog card slightly upwards with the right
+thumb, making a space of from an eighth to a quarter of an inch wide, and holding the space, by squeezing the
+ends of the packet to be drawn out, between the thumb and second and third fingers. The use of the break
+during a shuffle makes it possible to throw any number of cards that are immediately above it, in one packet
+into the left hand, without disarranging their order. The break is used when not shuffling, to locate any particular
+card or position, and is infinitely superior to the common method of inserting the little finger. A break can be
+held firmly by a finger or thumb of either hand, and entirely concealed by the other fingers of the same hand. It
+is also the principal aid in the blind riffles and cuts.
+
+=item * Throw
+
+To pass from the right hand to the left, during a shuffle, a certain number of cards in one packet, thereby
+retaining their order. A throw may be required at the beginning, during the process, or at the end of a shuffle;
+and the packet to be thrown may be located by the jog, or break, or by both.
+
+=item * Top Card
+
+The card on top of packet held in the left hand, or the original top card of the full deck, which about to be
+shuffled.
+
+=item * Riffle
+
+The modern method of shuffling on the table by springing, the ends of two packets into each other.
+
+=item * Crimp
+
+To bend one or a number of cards, so that they may be distinguished or located. 
+
+=back
+
+
 =head1 AUTHOR
 
 Jose Castro, C<< <cog at cpan.org> >>
@@ -1230,7 +1402,7 @@ L<http://search.cpan.org/dist/Games-Cards-ShuffleTrack/>
 
 =head1 SEE ALSO
 
-The following is a very, very, very, very extremely small list of recommended books:
+The following is an extremely small list of recommended books:
 
 =over 4
 
